NineToothed Documentation
=========================

**NineToothed** is a domain-specific language (DSL) based on Triton, offering higher-level abstractions. Through its tensor-oriented metaprogramming (TOM) model, it empowers developers to write high-performance compute kernels intuitively, without the need to manage low-level details like pointer arithmetic or memory access.

.. note::

   This project is under active development.

.. toctree::
   :maxdepth: 2

   installation
   basics
   python_api
